==> ViesCraftTweaker-1.11.2-1.2.4-sources.jar: se/gory_moon/vctweaker/fuel/FuelHandler.java <==
package se.gory_moon.vctweaker.fuel;

import com.google.common.collect.Lists;
import com.viesis.viescraft.configs.ViesCraftConfig;
import com.viesis.viescraft.init.InitItemsVC;
import net.minecraft.block.Block;
import net.minecraft.block.material.Material;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.*;
import net.minecraftforge.fml.common.registry.GameRegistry;
import se.gory_moon.vctweaker.VCTweaker;

import java.util.ArrayList;

public class FuelHandler {

    private static ArrayList<String> fuels = Lists.newArrayList();

    public static void refreshConfigList(String[] list) {
        fuels.clear();
        for (String s: list) {
            String[] parts = s.split(":");

            String tmp = "";
            if (parts.length < 3)
                tmp = ":*";

            fuels.add(s + tmp);
        }
    }

    private static boolean containsItem(String location, int meta) {
        return fuels.contains(location + ":" + meta) || fuels.contains(location + ":*");
    }

    private static boolean isItemValid(boolean flag) {
        return (VCTweaker.Configs.isWhitelist && !flag) || (!VCTweaker.Configs.isWhitelist && flag);
    }

    public static int getItemBurnTime(ItemStack stack) {
        if (stack.func_190926_b()) {
            return 0;
        } else {
            Item item = stack.func_77973_b();

            if ("minecraft".equals(item.getRegistryName().func_110624_b()) || !VCTweaker.Configs.modedIgnoreList) {
                if (item instanceof ItemBlock && Block.func_149634_a(item) != Blocks.field_150350_a) {
                    Block block = Block.func_149634_a(item);
                    boolean flag = containsItem(block.getRegistryName().toString(), stack.func_77960_j()) || (VCTweaker.Configs.woodMaterial && block.func_176223_P().func_185904_a() == Material.field_151575_d);
                    if (isItemValid(flag))
                        return 0;
                } else {
                    boolean flag = containsItem(item.getRegistryName().toString(), stack.func_77960_j());
                    if (isItemValid(flag))
                        return 0;
                }
            }

            if (ViesCraftConfig.vanillaFuel) {

                int val = item == Item.func_150898_a(Blocks.field_150404_cg) ? 670:
                                (item instanceof ItemBoat ? 4000 :
                                        (item == Items.field_151044_h ? 16000 :
                                                (item == Items.field_151072_bj ? 24000 :
                                                        (item == Item.func_150898_a(Blocks.field_150402_ci) ? 160000 :
                                                                (item == Items.field_151129_at ? 200000: 0)))));

                val = (item == Items.field_151055_y) ||
                        (item == Items.field_151054_z) ||
                        (item == Item.func_150898_a(Blocks.field_150345_g)) ||
                        (item == Item.func_150898_a(Blocks.field_150471_bO)) ||
                        (item == Item.func_150898_a(Blocks.field_150325_L)) ? 1000 : val;

                val = (item instanceof ItemDoor && item != Items.field_151139_aw) ||
                        (item == Items.field_151155_ap) ? 2000 : val;

                val = (item == Item.func_150898_a(Blocks.field_150376_bx) ? 1500 :
                        (item == Item.func_150898_a(Blocks.field_150468_ap) ||
                        (item == Items.field_151031_f) ||
                        (item == Items.field_151112_aM) ||
                        (Block.func_149634_a(item).func_176223_P().func_185904_a() == Material.field_151575_d)) ? 3000 : val);

                if (val > 0)
                    return val;
            }

            if ((item instanceof ItemTool && "WOOD".equals(((ItemTool)item).func_77861_e())) || (item instanceof ItemSword && "WOOD".equals(((ItemSword)item).func_150932_j())) || (item instanceof ItemHoe && "WOOD".equals(((ItemHoe)item).func_77842_f())))
                return 2000;

            return item == InitItemsVC.viesoline_pellets ? ViesCraftConfig.viesolineBurnTime * 20 * 10 : (ViesCraftConfig.outsideModFuel ? GameRegistry.getFuelValue(stack) : 0);
        }
    }

}

==> ViesCraftTweaker-1.12.2-2.2.8-sources.jar: se/gory_moon/vctweaker/fuel/FuelHandler.java <==
package se.gory_moon.vctweaker.fuel;

import com.google.common.collect.Lists;
import com.viesis.viescraft.configs.ViesCraftConfig;
import com.viesis.viescraft.init.InitItemsVC;
import net.minecraft.block.Block;
import net.minecraft.block.material.Material;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.*;
import net.minecraftforge.event.ForgeEventFactory;
import se.gory_moon.vctweaker.VCTweakerContainer;

import java.util.ArrayList;

public class FuelHandler {

    private static ArrayList<String> fuels = Lists.newArrayList();

    public static void refreshConfigList(String[] list) {
        fuels.clear();
        for (String s: list) {
            String[] parts = s.split(":");

            String tmp = "";
            if (parts.length < 3)
                tmp = ":*";

            fuels.add(s + tmp);
        }
    }

    private static boolean containsItem(String location, int meta) {
        return fuels.contains(location + ":" + meta) || fuels.contains(location + ":*");
    }

    private static boolean isItemValid(boolean flag) {
        return (VCTweakerContainer.Configs.isWhitelist && !flag) || (!VCTweakerContainer.Configs.isWhitelist && flag);
    }

    public static int getItemBurnTime(ItemStack stack) {
        if (stack.func_190926_b()) {
            return 0;
        } else {
            Item item = stack.func_77973_b();

            if ("minecraft".equals(item.getRegistryName().func_110624_b()) || !VCTweakerContainer.Configs.moddedIgnoreList) {
                if (item instanceof ItemBlock && Block.func_149634_a(item) != Blocks.field_150350_a) {
                    Block block = Block.func_149634_a(item);
                    boolean flag = containsItem(block.getRegistryName().toString(), stack.func_77960_j()) || (VCTweakerContainer.Configs.woodMaterial && block.func_176223_P().func_185904_a() == Material.field_151575_d);
                    if (isItemValid(flag))
                        return 0;
                } else {
                    boolean flag = containsItem(item.getRegistryName().toString(), stack.func_77960_j());
                    if (isItemValid(flag))
                        return 0;
                }
            }

            if (ViesCraftConfig.vanillaFuel) {

                int val = item == Item.func_150898_a(Blocks.field_150404_cg) ? 670:
                                (item instanceof ItemBoat ? 4000 :
                                        (item == Items.field_151044_h ? 16000 :
                                                (item == Items.field_151072_bj ? 24000 :
                                                        (item == Item.func_150898_a(Blocks.field_150402_ci) ? 160000 :
                                                                (item == Items.field_151129_at ? 200000: 0)))));

                val = (item == Items.field_151055_y) ||
                        (item == Items.field_151054_z) ||
                        (item == Item.func_150898_a(Blocks.field_150345_g)) ||
                        (item == Item.func_150898_a(Blocks.field_150471_bO)) ||
                        (item == Item.func_150898_a(Blocks.field_150325_L)) ? 1000 : val;

                val = (item instanceof ItemDoor && item != Items.field_151139_aw) ||
                        (item == Items.field_151155_ap) ? 2000 : val;

                val = (item == Item.func_150898_a(Blocks.field_150376_bx) ? 1500 :
                        (item == Item.func_150898_a(Blocks.field_150468_ap) ||
                        (item == Items.field_151031_f) ||
                        (item == Items.field_151112_aM) ||
                        (Block.func_149634_a(item).func_176223_P().func_185904_a() == Material.field_151575_d)) ? 3000 : val);

                if (val > 0)
                    return val;
            }

            if ((item instanceof ItemTool && "WOOD".equals(((ItemTool)item).func_77861_e())) || (item instanceof ItemSword && "WOOD".equals(((ItemSword)item).func_150932_j())) || (item instanceof ItemHoe && "WOOD".equals(((ItemHoe)item).func_77842_f())))
                return 2000;

            return item == InitItemsVC.VIESOLINE_PELLETS ? ViesCraftConfig.viesolineBurnTime * 20 * 10 : (ViesCraftConfig.outsideModFuel ? ForgeEventFactory.getItemBurnTime(stack) : 0);
        }
    }

}
